@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_FETCHJOBCALENDAR_P_H
-#define AKONADI_FETCHJOBCALENDAR_P_H
+#pragma once
 
 #include "calendarbase_p.h"
 #include "fetchjobcalendar.h"
@@ -35,4 +34,3 @@ private:
 };
 }
 
-#endif
