@@ -8,8 +8,7 @@
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef AKONADI_INCIDENCECHANGER_P_H
-#define AKONADI_INCIDENCECHANGER_P_H
+#pragma once
 
 #include "history.h"
 #include "incidencechanger.h"
@@ -221,7 +220,7 @@ public:
     {
         if (change->type == IncidenceChanger::ChangeTypeDelete) {
             DeletionChange::Ptr deletion = change.staticCast<DeletionChange>();
-            for (Akonadi::Item::Id id : qAsConst(deletion->mItemIds)) {
+            for (Akonadi::Item::Id id : std::as_const(deletion->mItemIds)) {
                 Q_ASSERT(!m_itemIdsInOperation.contains(id));
                 m_itemIdsInOperation.insert(id);
             }
@@ -355,4 +354,3 @@ private:
 };
 }
 
-#endif
