@@ -6,17 +6,18 @@
 */
 
 #include "incidencefetchjob_p.h"
+#include <KCalendarCore/Event>
+#include <KCalendarCore/Journal>
 #include <collectionfetchjob.h>
 #include <collectionfetchscope.h>
 #include <itemfetchjob.h>
 #include <itemfetchscope.h>
-#include <KCalendarCore/Event>
-#include <KCalendarCore/Journal>
 #include <kcalendarcore/todo.h>
 
 using namespace Akonadi;
 
-Akonadi::IncidenceFetchJob::IncidenceFetchJob(QObject *parent) : Job(parent)
+Akonadi::IncidenceFetchJob::IncidenceFetchJob(QObject *parent)
+    : Job(parent)
 {
     m_mimeTypeChecker.addWantedMimeType(QStringLiteral("text/calendar"));
 }
@@ -28,11 +29,9 @@ Item::List Akonadi::IncidenceFetchJob::items() const
 
 void Akonadi::IncidenceFetchJob::doStart()
 {
-    CollectionFetchJob *job = new CollectionFetchJob(Collection::root(), CollectionFetchJob::Recursive, this);
-    job->fetchScope().setContentMimeTypes(QStringList() << QStringLiteral("text/calendar")
-                                                        << KCalendarCore::Event::eventMimeType()
-                                                        << KCalendarCore::Todo::todoMimeType()
-                                                        << KCalendarCore::Journal::journalMimeType());
+    auto job = new CollectionFetchJob(Collection::root(), CollectionFetchJob::Recursive, this);
+    job->fetchScope().setContentMimeTypes(QStringList() << QStringLiteral("text/calendar") << KCalendarCore::Event::eventMimeType()
+                                                        << KCalendarCore::Todo::todoMimeType() << KCalendarCore::Journal::journalMimeType());
     connect(job, &CollectionFetchJob::result, this, &IncidenceFetchJob::collectionFetchResult);
 }
 
@@ -41,7 +40,7 @@ void Akonadi::IncidenceFetchJob::collectionFetchResult(KJob *job)
     if (job->error()) { // handled in base class
         return;
     }
-    auto *fetch = qobject_cast<CollectionFetchJob *>(job);
+    auto fetch = qobject_cast<CollectionFetchJob *>(job);
     Q_ASSERT(fetch);
 
     if (fetch->collections().isEmpty()) {
@@ -54,7 +53,7 @@ void Akonadi::IncidenceFetchJob::collectionFetchResult(KJob *job)
         if (!m_mimeTypeChecker.isWantedCollection(col) || col.isVirtual()) {
             continue;
         }
-        auto *itemFetch = new ItemFetchJob(col, this);
+        auto itemFetch = new ItemFetchJob(col, this);
         itemFetch->fetchScope().fetchFullPayload(true);
         connect(itemFetch, &ItemFetchJob::result, this, &IncidenceFetchJob::itemFetchResult);
         ++m_jobCount;
@@ -67,7 +66,7 @@ void Akonadi::IncidenceFetchJob::itemFetchResult(KJob *job)
         return;
     }
     --m_jobCount;
-    auto *fetch = qobject_cast<ItemFetchJob *>(job);
+    auto fetch = qobject_cast<ItemFetchJob *>(job);
     const auto items = fetch->items();
     for (const Item &item : items) {
         if (!m_mimeTypeChecker.isWantedItem(item)) {
