@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_INCIDENCEFETCHJOB_P_H
-#define AKONADI_INCIDENCEFETCHJOB_P_H
+#pragma once
 
 #include <KCalendarCore/Incidence>
 #include <item.h>
@@ -40,4 +39,3 @@ private:
 };
 }
 
-#endif
